@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON;
 
 # ABSTRACT: Dist::Iller config
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0308';
+our $VERSION = '0.0309';
 
 use Moose;
 use namespace::autoclean;
@@ -115,6 +115,7 @@ sub is_cpan_release {
     my $self = shift;
     return $ENV{'FAKE_RELEASE'} || $self->is_private ? 0 : 1;
 }
+
 sub add_default_github {
     my $self = shift;
     # check git config
@@ -157,8 +158,8 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0308"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0308" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0308"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0308" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0309"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0309" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0309"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0309" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" />
 </p>
 
@@ -166,7 +167,7 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =head1 VERSION
 
-Version 0.0308, released 2016-02-18.
+Version 0.0309, released 2016-04-21.
 
 
 
@@ -554,7 +555,7 @@ If set to a true value this will include [FakeRelease] and remove either [Upload
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>.
+L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>
 
 =head1 HOMEPAGE
 
